Exporting

## 6.3 Exporting

Each structure in the current structure list can be exported to file. The options for exporting a structure can be found in the File–Export Structure menu. The full list of export options are shown in Fig. 11.

Figure 11: `NanoCap` export structure options

The export options include the ability to select which lattices are saved and in what file format. Currently only a simple file format is implemented which contains a minimum amount of data (the number of points and positions). In addition to the topology of the structure, structural information can also be saved. This includes energies, dimensions, connectivity (ring statistics) amongst other properties. Using the rendering capabilities of `NanoCap`, images of the structure can also be automatically saved. This includes a series of images that capture a full rotation of the structure. These images can be encoded into a movie to simplify future inspection of the stored structure. Finally, the export options require a parent directly to save the aforementioned data. Within this directory, a new directory will be created whose name uniquely identifies the current structure.